from .models import Questboard, Quest
from django import forms

class QuestboardForm(forms.ModelForm):
    class Meta:
        model = Questboard
        fields = ['name', 'description', 'required_stars']
        widgets = {
            'description' : forms.Textarea(), 
            'required_stars' : forms.NumberInput(attrs = {'min' : 0}),
        }

class QuestForm(forms.ModelForm):
    class Meta:
        model = Quest
        fields = ['board_id', 'name', 'description', 'stars', 'for_everyone','student1','student2', 'student3']
        widgets = {'board_id' : forms.HiddenInput(),
                   'description' : forms.Textarea(),
                   'stars' : forms.NumberInput(attrs = {'min' : 0}),
                   'student1' : forms.HiddenInput(),
                   'student2' : forms.HiddenInput(),
                   'student3' : forms.HiddenInput(),
                  }

#Form for signing up to quests
class StudentSignupForm(forms.Form):
    quest_id = forms.IntegerField(widget = forms.HiddenInput())
    name = forms.CharField(max_length = 60)

class EditQuestForm(QuestForm):
    quest_id = forms.IntegerField(widget = forms.HiddenInput())

class DeleteQuestForm(forms.Form):
    quest_id = forms.IntegerField(widget = forms.HiddenInput()) 

class EditBoardNameForm(forms.Form):
    board_id = forms.IntegerField(widget = forms.HiddenInput())
    name = forms.CharField(max_length = 50)

class EditBoardDescForm(forms.Form):
    board_id = forms.IntegerField(widget = forms.HiddenInput())
    description = forms.CharField(max_length = 300, widget = forms.Textarea())

class EditBoardStarsForm(forms.Form):
    board_id = forms.IntegerField(widget = forms.HiddenInput())
    required_stars = forms.IntegerField(widget = forms.NumberInput(attrs = {'min' : 0}))


