from django.shortcuts import redirect, render
from django.http import HttpRequest
from .models import Quest, Questboard
from .forms import *

#View that displays a questboard, allows it to be edited as a teacher
def edit_board_view(request, pk):
    return render(
        request,
        'board/edit_board.html',
        {
            'questboard' : Questboard.objects.get(pk=pk),
            'quests' : Quest.objects.filter(board_id=pk),
            'share_url' : get_share_url(request, pk),
            'edit_board_name_form' : EditBoardNameForm(initial={'board_id' : pk}),
            'edit_board_desc_form' : EditBoardDescForm(initial={'board_id' : pk}),
            'edit_board_stars_form' : EditBoardStarsForm(initial={'board_id' : pk}),
            'add_quest_form' : QuestForm(initial={'board_id' : pk}),
            'edit_quest_form' : EditQuestForm(auto_id = 'edit_%s'),
            'delete_quest_form' : DeleteQuestForm(auto_id = 'delete_%s'),
        }
    )

#View that displays a questboard, allows students to sign up for quests
def view_board_view(request, pk):
    return render(
        request,
        'board/view_board.html',
        {   
            'questboard' : Questboard.objects.get(pk=pk),
            'quests' : Quest.objects.filter(board_id=pk),
            'share_url' : get_share_url(request, pk),
            'signup_form' : StudentSignupForm(auto_id = 'signup_%s')
        }
    )

#get the url of the questboard so it can be shared
def get_share_url(request, pk):
    return request.build_absolute_uri('/questboard/view/' + str(pk))

#FUNCTIONS FOR MANIPULATING QUESTS 

def add_quest(request):
    if request.method == "POST":
        filled_form = QuestForm(request.POST)
        if filled_form.is_valid():
            filled_form.save()
    return redirect(request.META.get('HTTP_REFERER', '/'))

#signs students up to quests
def student_signup(request): 
    if request.method == "POST":
        filled_form = StudentSignupForm(request.POST)
        if filled_form.is_valid():
            quest_to_edit = Quest.objects.get(pk=filled_form.cleaned_data['quest_id'])
            student_name = filled_form.cleaned_data['name']
            if quest_to_edit.student1 == '':
                quest_to_edit.student1 = student_name
            elif quest_to_edit.student2 == '':
                quest_to_edit.student2 = student_name
            elif quest_to_edit.student3 == '':
                quest_to_edit.student3 = student_name  
            quest_to_edit.save()
    return redirect(request.META.get('HTTP_REFERER', '/'))   #PLEASE CHANGE THESE TO FUNCTION FOR CLARITY!!!

def edit_quest(request):
    if request.method == "POST":
        filled_form = EditQuestForm(request.POST)
        if filled_form.is_valid():
            quest_to_edit = Quest.objects.get(pk=filled_form.cleaned_data['quest_id'])
            quest_to_edit.name = filled_form.cleaned_data['name']
            quest_to_edit.description = filled_form.cleaned_data['description']
            quest_to_edit.stars = filled_form.cleaned_data['stars']
            quest_to_edit.for_everyone = filled_form.cleaned_data['for_everyone']
            quest_to_edit.save()
            return redirect(request.META.get('HTTP_REFERER', '/'))

def delete_quest(request):
    if request.method == "POST":
        filled_form = DeleteQuestForm(request.POST)
        if filled_form.is_valid():
            quest_to_delete = Quest.objects.get(pk=filled_form.cleaned_data['quest_id'])
            quest_to_delete.delete()
    return redirect(request.META.get('HTTP_REFERER', '/'))    

#FUNCTIONS FOR MANIPULATING QUESTBOARDS

def edit_board_name(request):
    if request.method == "POST":
        filled_form = EditBoardNameForm(request.POST)
        if filled_form.is_valid():
            board_to_edit = Questboard.objects.get(pk=filled_form.cleaned_data['board_id'])
            board_name = filled_form.cleaned_data['name']
            board_to_edit.name = board_name
            board_to_edit.save()
    return redirect(request.META.get('HTTP_REFERER', '/')) 

def edit_board_desc(request):
    if request.method == "POST":
        filled_form = EditBoardDescForm(request.POST)
        if filled_form.is_valid():
            board_to_edit = Questboard.objects.get(pk=filled_form.cleaned_data['board_id'])
            board_desc = filled_form.cleaned_data['description']
            board_to_edit.description = board_desc
            board_to_edit.save()
    return redirect(request.META.get('HTTP_REFERER', '/'))   

def edit_board_stars(request):
    if request.method == "POST":
        filled_form = EditBoardStarsForm(request.POST)

        if filled_form.is_valid():
            board_to_edit = Questboard.objects.get(pk=filled_form.cleaned_data['board_id'])
            board_stars = filled_form.cleaned_data['required_stars']
            board_to_edit.required_stars = board_stars
            board_to_edit.save()
            return redirect(request.META.get('HTTP_REFERER', '/'))   
        